@@ -7,6 +7,8 @@ of stack usage.
 """
 
 from xdis.opcodes.base import (
+    extended_format_ATTR,
+    extended_format_RETURN_VALUE,
     finalize_opcodes,
     init_opdata,
     jrel_op,
@@ -45,3 +47,9 @@ jrel_op(l, "JUMP_IF_NOT_DEBUG", 204, conditional=True)
 update_pj3(globals(), l)
 
 finalize_opcodes(l)
+
+opcode_extended_fmt = {
+    "LOAD_ATTR": extended_format_ATTR,
+    "RETURN_VALUE": extended_format_RETURN_VALUE,
+    "STORE_ATTR": extended_format_ATTR,
+}
