@@ -33,7 +33,7 @@ from xdis.opcodes.base import(
     update_pj3
     )
 
-from xdis.opcodes.opcode_33 import extended_format_MAKE_FUNCTION
+from xdis.opcodes.opcode_33 import extended_format_MAKE_FUNCTION, extended_format_ATTR
 import xdis.opcodes.opcode_36 as opcode_36
 
 version = 3.7
@@ -141,9 +141,11 @@ opcode_arg_fmt = {
 opcode_extended_fmt = {
     "CALL_FUNCTION": opcode_36.extended_format_CALL_FUNCTION,
     "CALL_METHOD": opcode_36.extended_format_CALL_METHOD,
+    "LOAD_ATTR": extended_format_ATTR,
     "MAKE_FUNCTION": extended_format_MAKE_FUNCTION,
     "RAISE_VARARGS": extended_format_RAISE_VARARGS,
     "RETURN_VALUE": extended_format_RETURN_VALUE,
+    "STORE_ATTR": extended_format_ATTR,
 }
 
 update_pj3(globals(), l)
